.. _formatters:

=================================
Formatters
=================================


JSON
=============



CSV
==============



XLS
==============
Dump timeseries into spreadsheet files that are are compatible with Excel,
OpenOffice.org Calc, and Gnumeric.
It requires the xlwt_ python package.

.. _xlwt: http://pypi.python.org/pypi/xlwt

